@@ -11,7 +11,6 @@
 # under the License.
 
 
-from openstack.identity import identity_service
 from openstack import resource
 
 
@@ -19,24 +18,21 @@ class Trust(resource.Resource):
     resource_key = 'trust'
     resources_key = 'trusts'
     base_path = '/OS-TRUST/trusts'
-    service = identity_service.IdentityService()
 
     # capabilities
     allow_create = True
-    allow_get = True
+    allow_fetch = True
     allow_delete = True
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'trustor_user_id', 'trustee_user_id')
+        'trustor_user_id', 'trustee_user_id'
+    )
 
     # Properties
     #: A boolean indicating whether the trust can be issued by the trustee as
     #: a regulart trust. Default is ``False``.
     allow_redelegation = resource.Body('allow_redelegation', type=bool)
-    #: If ``impersonation`` is set to ``False``, then the token's ``user``
-    #: attribute will represent that of the trustee. *Type: bool*
-    is_impersonation = resource.Body('impersonation', type=bool)
     #: Specifies the expiration time of the trust. A trust may be revoked
     #: ahead of expiration. If the value represents a time in the past,
     #: the trust is deactivated.
