@@ -14,7 +14,7 @@
 test_security_groups
 ----------------------------------
 
-Functional tests for `shade` security_groups resource.
+Functional tests for security_groups resource.
 """
 
 from openstack.tests.functional import base
