@@ -19,6 +19,7 @@ from openstack.block_storage.v2 import capabilities
 from openstack.block_storage.v2 import limits
 from openstack.block_storage.v2 import quota_class_set
 from openstack.block_storage.v2 import quota_set
+from openstack.block_storage.v2 import service
 from openstack.block_storage.v2 import snapshot
 from openstack.block_storage.v2 import stats
 from openstack.block_storage.v2 import type
@@ -73,10 +74,13 @@ class TestVolume(TestVolumeProxy):
         self.verify_create(self.proxy.create_volume, volume.Volume)
 
     def test_volume_delete(self):
-        self.verify_delete(self.proxy.delete_volume, volume.Volume, False)
-
-    def test_volume_delete_ignore(self):
-        self.verify_delete(self.proxy.delete_volume, volume.Volume, True)
+        self._verify(
+            "openstack.block_storage.v2.volume.Volume.delete",
+            self.proxy.delete_volume,
+            method_args=["value"],
+            expected_args=[self.proxy],
+            expected_kwargs={"params": {"cascade": False}},
+        )
 
     def test_volume_delete_force(self):
         self._verify(
@@ -173,7 +177,7 @@ class TestVolumeActions(TestVolumeProxy):
             expected_args=[self.proxy, True],
         )
 
-    def test_volume_reset_volume_status(self):
+    def test_volume_reset_status(self):
         self._verify(
             "openstack.block_storage.v2.volume.Volume.reset_status",
             self.proxy.reset_volume_status,
@@ -337,10 +341,10 @@ class TestBackup(TestVolumeProxy):
             expected_kwargs={'volume_id': 'vol_id', 'name': 'name'},
         )
 
-    def test_backup_reset(self):
+    def test_backup_reset_status(self):
         self._verify(
-            "openstack.block_storage.v2.backup.Backup.reset",
-            self.proxy.reset_backup,
+            "openstack.block_storage.v2.backup.Backup.reset_status",
+            self.proxy.reset_backup_status,
             method_args=["value", "new_status"],
             expected_args=[self.proxy, "new_status"],
         )
@@ -395,6 +399,9 @@ class TestSnapshot(TestVolumeProxy):
     def test_snapshot_create_attrs(self):
         self.verify_create(self.proxy.create_snapshot, snapshot.Snapshot)
 
+    def test_snapshot_update(self):
+        self.verify_update(self.proxy.update_snapshot, snapshot.Snapshot)
+
     def test_snapshot_delete(self):
         self.verify_delete(
             self.proxy.delete_snapshot, snapshot.Snapshot, False
@@ -403,14 +410,41 @@ class TestSnapshot(TestVolumeProxy):
     def test_snapshot_delete_ignore(self):
         self.verify_delete(self.proxy.delete_snapshot, snapshot.Snapshot, True)
 
-    def test_reset(self):
+    def test_snapshot_reset_status(self):
         self._verify(
-            "openstack.block_storage.v2.snapshot.Snapshot.reset",
-            self.proxy.reset_snapshot,
+            "openstack.block_storage.v2.snapshot.Snapshot.reset_status",
+            self.proxy.reset_snapshot_status,
             method_args=["value", "new_status"],
             expected_args=[self.proxy, "new_status"],
         )
 
+    def test_snapshot_manage(self):
+        kwargs = {
+            "volume_id": "fake_id",
+            "remote_source": "fake_volume",
+            "snapshot_name": "fake_snap",
+            "description": "test_snap",
+            "property": {"k": "v"},
+        }
+        self._verify(
+            "openstack.block_storage.v2.snapshot.Snapshot.manage",
+            self.proxy.manage_snapshot,
+            method_kwargs=kwargs,
+            method_result=snapshot.Snapshot(id="fake_id"),
+            expected_args=[self.proxy],
+            expected_kwargs=kwargs,
+            expected_result=snapshot.Snapshot(id="fake_id"),
+        )
+
+    def test_snapshot_unmanage(self):
+        self._verify(
+            "openstack.block_storage.v2.snapshot.Snapshot.unmanage",
+            self.proxy.unmanage_snapshot,
+            method_args=["value"],
+            expected_args=[self.proxy],
+            expected_result=None,
+        )
+
     def test_get_snapshot_metadata(self):
         self._verify(
             "openstack.block_storage.v2.snapshot.Snapshot.fetch_metadata",
@@ -614,3 +648,50 @@ class TestQuotaSet(TestVolumeProxy):
                 "The signature of 'update_quota_set' has changed ",
                 str(w[-1]),
             )
+
+
+class TestService(TestVolumeProxy):
+    def test_services(self):
+        self.verify_list(self.proxy.services, service.Service)
+
+    def test_enable_service(self):
+        self._verify(
+            'openstack.block_storage.v2.service.Service.enable',
+            self.proxy.enable_service,
+            method_args=["value"],
+            expected_args=[self.proxy],
+        )
+
+    def test_disable_service(self):
+        self._verify(
+            'openstack.block_storage.v2.service.Service.disable',
+            self.proxy.disable_service,
+            method_args=["value"],
+            expected_kwargs={"reason": None},
+            expected_args=[self.proxy],
+        )
+
+    def test_thaw_service(self):
+        self._verify(
+            'openstack.block_storage.v2.service.Service.thaw',
+            self.proxy.thaw_service,
+            method_args=["value"],
+            expected_args=[self.proxy],
+        )
+
+    def test_freeze_service(self):
+        self._verify(
+            'openstack.block_storage.v2.service.Service.freeze',
+            self.proxy.freeze_service,
+            method_args=["value"],
+            expected_args=[self.proxy],
+        )
+
+    def test_failover_service(self):
+        self._verify(
+            'openstack.block_storage.v2.service.Service.failover',
+            self.proxy.failover_service,
+            method_args=["value"],
+            expected_args=[self.proxy],
+            expected_kwargs={"backend_id": None},
+        )
