@@ -9,6 +9,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import copy
 from unittest import mock
 
 from keystoneauth1 import adapter
@@ -18,6 +20,7 @@ from openstack.tests.unit import base
 
 
 FAKE_ID = "ffa9bc5e-1172-4021-acaf-cdcd78a9584d"
+FAKE_VOLUME_ID = "5aa119a8-d25b-45a7-8d1b-88e127885635"
 
 SNAPSHOT = {
     "status": "creating",
@@ -90,15 +93,48 @@ class TestSnapshotActions(base.TestCase):
         self.sess = mock.Mock(spec=adapter.Adapter)
         self.sess.get = mock.Mock()
         self.sess.post = mock.Mock(return_value=self.resp)
-        self.sess.default_microversion = None
 
-    def test_reset(self):
+    def test_reset_status(self):
         sot = snapshot.Snapshot(**SNAPSHOT)
 
-        self.assertIsNone(sot.reset(self.sess, 'new_status'))
+        self.assertIsNone(sot.reset_status(self.sess, 'new_status'))
 
         url = f'snapshots/{FAKE_ID}/action'
         body = {'os-reset_status': {'status': 'new_status'}}
-        self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion
+        self.sess.post.assert_called_with(url, json=body)
+
+    def test_manage(self):
+        resp = mock.Mock()
+        resp.body = {'snapshot': copy.deepcopy(SNAPSHOT)}
+        resp.json = mock.Mock(return_value=resp.body)
+        resp.headers = {}
+        resp.status_code = 202
+
+        self.sess.post = mock.Mock(return_value=resp)
+
+        sot = snapshot.Snapshot.manage(
+            self.sess, volume_id=FAKE_VOLUME_ID, ref=FAKE_ID
         )
+
+        self.assertIsNotNone(sot)
+
+        url = '/os-snapshot-manage'
+        body = {
+            'snapshot': {
+                'volume_id': FAKE_VOLUME_ID,
+                'ref': FAKE_ID,
+                'name': None,
+                'description': None,
+                'metadata': None,
+            }
+        }
+        self.sess.post.assert_called_with(url, json=body)
+
+    def test_unmanage(self):
+        sot = snapshot.Snapshot(**SNAPSHOT)
+
+        self.assertIsNone(sot.unmanage(self.sess))
+
+        url = f'snapshots/{FAKE_ID}/action'
+        body = {'os-unmanage': None}
+        self.sess.post.assert_called_with(url, json=body)
