@@ -76,7 +76,7 @@ class TestVolume(base.TestCase):
         self.resp.status_code = 200
         self.resp.json = mock.Mock(return_value=self.resp.body)
         self.sess = mock.Mock(spec=adapter.Adapter)
-        self.sess.default_microversion = '3.60'
+        self.sess.default_microversion = '3.71'
         self.sess.post = mock.Mock(return_value=self.resp)
         self.sess._get_connection = mock.Mock(return_value=self.cloud)
 
@@ -100,6 +100,7 @@ class TestVolume(base.TestCase):
                 "project_id": "project_id",
                 "created_at": "created_at",
                 "updated_at": "updated_at",
+                "properties": "metadata",
                 "limit": "limit",
                 "marker": "marker",
             },
@@ -164,6 +165,28 @@ class TestVolume(base.TestCase):
             url, json=body, microversion=sot._max_microversion
         )
 
+    def test_complete_extend(self):
+        sot = volume.Volume(**VOLUME)
+
+        self.assertIsNone(sot.complete_extend(self.sess))
+
+        url = f'volumes/{FAKE_ID}/action'
+        body = {'os-extend_volume_completion': {'error': False}}
+        self.sess.post.assert_called_with(
+            url, json=body, microversion=sot._max_microversion
+        )
+
+    def test_complete_extend_error(self):
+        sot = volume.Volume(**VOLUME)
+
+        self.assertIsNone(sot.complete_extend(self.sess, error=True))
+
+        url = f'volumes/{FAKE_ID}/action'
+        body = {'os-extend_volume_completion': {'error': True}}
+        self.sess.post.assert_called_with(
+            url, json=body, microversion=sot._max_microversion
+        )
+
     def test_set_volume_readonly(self):
         sot = volume.Volume(**VOLUME)
 
@@ -214,7 +237,7 @@ class TestVolume(base.TestCase):
         self.assertIsNone(sot.set_image_metadata(self.sess, {'foo': 'bar'}))
 
         url = f'volumes/{FAKE_ID}/action'
-        body = {'os-set_image_metadata': {'foo': 'bar'}}
+        body = {'os-set_image_metadata': {'metadata': {'foo': 'bar'}}}
         self.sess.post.assert_called_with(
             url, json=body, microversion=sot._max_microversion
         )
@@ -661,7 +684,7 @@ class TestVolume(base.TestCase):
         self.sess.post.assert_called_with(
             url,
             json=body,
-            microversion='3.60',
+            microversion=sot._max_microversion,
             headers={},
             params={},
         )
