@@ -26,15 +26,15 @@ EXAMPLE = {
     'description': '1',
     'enabled': True,
     'id': IDENTIFIER,
-    'links': {'self': 'http://example.com/identity/v3/domains/id'},
+    'links': {'self': f'http://example.com/identity/v3/domains/{IDENTIFIER}'},
     'name': '4',
+    'options': {'foo': 'bar'},
 }
 
 
 class TestDomain(base.TestCase):
-
     def setUp(self):
-        super(TestDomain, self).setUp()
+        super().setUp()
         self.sess = mock.Mock(spec=adapter.Adapter)
         self.sess.default_microversion = 1
         self.sess._get_connection = mock.Mock(return_value=self.cloud)
@@ -66,8 +66,13 @@ class TestDomain(base.TestCase):
                 'is_enabled': 'enabled',
                 'limit': 'limit',
                 'marker': 'marker',
+                'tags': 'tags',
+                'any_tags': 'tags-any',
+                'not_tags': 'not-tags',
+                'not_any_tags': 'not-tags-any',
             },
-            sot._query_mapping._mapping)
+            sot._query_mapping._mapping,
+        )
 
     def test_make_it(self):
         sot = domain.Domain(**EXAMPLE)
@@ -76,6 +81,7 @@ class TestDomain(base.TestCase):
         self.assertEqual(EXAMPLE['id'], sot.id)
         self.assertEqual(EXAMPLE['links'], sot.links)
         self.assertEqual(EXAMPLE['name'], sot.name)
+        self.assertDictEqual(EXAMPLE['options'], sot.options)
 
     def test_assign_role_to_user_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -84,12 +90,26 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.assign_role_to_user(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
+
+        self.sess.put.assert_called_with('domains/IDENTIFIER/users/1/roles/2')
+
+    def test_assign_inherited_role_to_user_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.put = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.assign_role_to_user(
+                self.sess, user.User(id='1'), role.Role(id='2'), True
+            )
+        )
 
         self.sess.put.assert_called_with(
-            'domains/IDENTIFIER/users/1/roles/2')
+            'OS-INHERIT/domains/IDENTIFIER/users/1/roles/2/inherited_to_projects'
+        )
 
     def test_assign_role_to_user_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -98,9 +118,9 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.assign_role_to_user(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
 
     def test_validate_user_has_role_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -109,12 +129,26 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.validate_user_has_role(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
+
+        self.sess.head.assert_called_with('domains/IDENTIFIER/users/1/roles/2')
+
+    def test_validate_user_has_inherited_role_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.head = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.validate_user_has_role(
+                self.sess, user.User(id='1'), role.Role(id='2'), True
+            )
+        )
 
         self.sess.head.assert_called_with(
-            'domains/IDENTIFIER/users/1/roles/2')
+            'OS-INHERIT/domains/IDENTIFIER/users/1/roles/2/inherited_to_projects'
+        )
 
     def test_validate_user_has_role_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -123,9 +157,9 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.validate_user_has_role(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
 
     def test_unassign_role_from_user_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -134,12 +168,28 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.unassign_role_from_user(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
 
         self.sess.delete.assert_called_with(
-            'domains/IDENTIFIER/users/1/roles/2')
+            'domains/IDENTIFIER/users/1/roles/2'
+        )
+
+    def test_unassign_inherited_role_from_user_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.delete = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.unassign_role_from_user(
+                self.sess, user.User(id='1'), role.Role(id='2'), True
+            )
+        )
+
+        self.sess.delete.assert_called_with(
+            'OS-INHERIT/domains/IDENTIFIER/users/1/roles/2/inherited_to_projects'
+        )
 
     def test_unassign_role_from_user_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -148,9 +198,9 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.unassign_role_from_user(
-                self.sess,
-                user.User(id='1'),
-                role.Role(id='2')))
+                self.sess, user.User(id='1'), role.Role(id='2'), False
+            )
+        )
 
     def test_assign_role_to_group_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -159,12 +209,26 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.assign_role_to_group(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
+
+        self.sess.put.assert_called_with('domains/IDENTIFIER/groups/1/roles/2')
+
+    def test_assign_inherited_role_to_group_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.put = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.assign_role_to_group(
+                self.sess, group.Group(id='1'), role.Role(id='2'), True
+            )
+        )
 
         self.sess.put.assert_called_with(
-            'domains/IDENTIFIER/groups/1/roles/2')
+            'OS-INHERIT/domains/IDENTIFIER/groups/1/roles/2/inherited_to_projects'
+        )
 
     def test_assign_role_to_group_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -173,9 +237,9 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.assign_role_to_group(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
 
     def test_validate_group_has_role_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -184,12 +248,28 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.validate_group_has_role(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
 
         self.sess.head.assert_called_with(
-            'domains/IDENTIFIER/groups/1/roles/2')
+            'domains/IDENTIFIER/groups/1/roles/2'
+        )
+
+    def test_validate_group_has_inherited_role_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.head = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.validate_group_has_role(
+                self.sess, group.Group(id='1'), role.Role(id='2'), True
+            )
+        )
+
+        self.sess.head.assert_called_with(
+            'OS-INHERIT/domains/IDENTIFIER/groups/1/roles/2/inherited_to_projects'
+        )
 
     def test_validate_group_has_role_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -198,9 +278,9 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.validate_group_has_role(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
 
     def test_unassign_role_from_group_good(self):
         sot = domain.Domain(**EXAMPLE)
@@ -209,12 +289,28 @@ class TestDomain(base.TestCase):
 
         self.assertTrue(
             sot.unassign_role_from_group(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
 
         self.sess.delete.assert_called_with(
-            'domains/IDENTIFIER/groups/1/roles/2')
+            'domains/IDENTIFIER/groups/1/roles/2'
+        )
+
+    def test_unassign_inherited_role_from_group_good(self):
+        sot = domain.Domain(**EXAMPLE)
+        resp = self.good_resp
+        self.sess.delete = mock.Mock(return_value=resp)
+
+        self.assertTrue(
+            sot.unassign_role_from_group(
+                self.sess, group.Group(id='1'), role.Role(id='2'), True
+            )
+        )
+
+        self.sess.delete.assert_called_with(
+            'OS-INHERIT/domains/IDENTIFIER/groups/1/roles/2/inherited_to_projects'
+        )
 
     def test_unassign_role_from_group_bad(self):
         sot = domain.Domain(**EXAMPLE)
@@ -223,6 +319,6 @@ class TestDomain(base.TestCase):
 
         self.assertFalse(
             sot.unassign_role_from_group(
-                self.sess,
-                group.Group(id='1'),
-                role.Role(id='2')))
+                self.sess, group.Group(id='1'), role.Role(id='2'), False
+            )
+        )
