@@ -10,13 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-from openstack.tests.unit import base
+from unittest import mock
 
 from openstack.key_manager.v1 import secret
+from openstack.tests.unit import base
 
 ID_VAL = "123"
-IDENTIFIER = 'http://localhost:9311/v1/secrets/%s' % ID_VAL
+IDENTIFIER = f'http://localhost:9311/v1/secrets/{ID_VAL}'
 EXAMPLE = {
     'algorithm': '1',
     'bit_length': '2',
@@ -31,37 +31,39 @@ EXAMPLE = {
     'secret_type': '9',
     'payload': '10',
     'payload_content_type': '11',
-    'payload_content_encoding': '12'
+    'payload_content_encoding': '12',
 }
 
 
 class TestSecret(base.TestCase):
-
     def test_basic(self):
         sot = secret.Secret()
         self.assertIsNone(sot.resource_key)
         self.assertEqual('secrets', sot.resources_key)
         self.assertEqual('/secrets', sot.base_path)
-        self.assertEqual('key-manager', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
-        self.assertDictEqual({"name": "name",
-                              "mode": "mode",
-                              "bits": "bits",
-                              "secret_type": "secret_type",
-                              "acl_only": "acl_only",
-                              "created": "created",
-                              "updated": "updated",
-                              "expiration": "expiration",
-                              "sort": "sort",
-                              "algorithm": "alg",
-                              "limit": "limit",
-                              "marker": "marker"},
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                "name": "name",
+                "mode": "mode",
+                "bits": "bits",
+                "secret_type": "secret_type",
+                "acl_only": "acl_only",
+                "created": "created",
+                "updated": "updated",
+                "expiration": "expiration",
+                "sort": "sort",
+                "algorithm": "alg",
+                "limit": "limit",
+                "marker": "marker",
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_make_it(self):
         sot = secret.Secret(**EXAMPLE)
@@ -78,10 +80,12 @@ class TestSecret(base.TestCase):
         self.assertEqual(EXAMPLE['updated'], sot.updated_at)
         self.assertEqual(EXAMPLE['secret_type'], sot.secret_type)
         self.assertEqual(EXAMPLE['payload'], sot.payload)
-        self.assertEqual(EXAMPLE['payload_content_type'],
-                         sot.payload_content_type)
-        self.assertEqual(EXAMPLE['payload_content_encoding'],
-                         sot.payload_content_encoding)
+        self.assertEqual(
+            EXAMPLE['payload_content_type'], sot.payload_content_type
+        )
+        self.assertEqual(
+            EXAMPLE['payload_content_encoding'], sot.payload_content_encoding
+        )
 
     def test_get_no_payload(self):
         sot = secret.Secret(id="id")
@@ -92,32 +96,42 @@ class TestSecret(base.TestCase):
         rv.json = mock.Mock(return_value=return_body)
         sess.get = mock.Mock(return_value=rv)
 
-        sot.get(sess)
+        sot.fetch(sess)
 
         sess.get.assert_called_once_with("secrets/id")
 
-    def _test_payload(self, sot, metadata, content_type):
-        content_type = "some/type"
-
+    def _test_payload(self, sot, metadata, content_type="some/type"):
         metadata_response = mock.Mock()
         # Use copy because the dict gets consumed.
         metadata_response.json = mock.Mock(return_value=metadata.copy())
 
         payload_response = mock.Mock()
-        payload = "secret info"
-        payload_response.text = payload
+        payload = b"secret info"
+        payload_response.content = payload
 
         sess = mock.Mock()
         sess.get = mock.Mock(side_effect=[metadata_response, payload_response])
 
-        rv = sot.get(sess)
+        rv = sot.fetch(sess)
 
         sess.get.assert_has_calls(
-            [mock.call("secrets/id",),
-             mock.call("secrets/id/payload",
-                       headers={"Accept": content_type})])
+            [
+                mock.call(
+                    "secrets/id",
+                ),
+                mock.call(
+                    "secrets/id/payload",
+                    headers={"Accept": content_type},
+                    skip_cache=False,
+                ),
+            ]
+        )
 
-        self.assertEqual(rv.payload, payload)
+        if content_type == "text/plain":
+            expected_payload = payload.decode("utf-8")
+        else:
+            expected_payload = payload
+        self.assertEqual(rv.payload, expected_payload)
         self.assertEqual(rv.status, metadata["status"])
 
     def test_get_with_payload_from_argument(self):
@@ -128,7 +142,18 @@ class TestSecret(base.TestCase):
 
     def test_get_with_payload_from_content_types(self):
         content_type = "some/type"
-        metadata = {"status": "fine",
-                    "content_types": {"default": content_type}}
+        metadata = {
+            "status": "fine",
+            "content_types": {"default": content_type},
+        }
+        sot = secret.Secret(id="id")
+        self._test_payload(sot, metadata, content_type)
+
+    def test_get_with_text_payload(self):
+        content_type = "text/plain"
+        metadata = {
+            "status": "fine",
+            "content_types": {"default": content_type},
+        }
         sot = secret.Secret(id="id")
         self._test_payload(sot, metadata, content_type)
